==> pytest-fixture-marker-0.1.0.tar.gz: pytest-fixture-marker-0.1.0/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import codecs
from setuptools import setup


def read(fname):
    file_path = os.path.join(os.path.dirname(__file__), fname)
    return codecs.open(file_path, encoding="utf-8").read()


setup(
    name="pytest-fixture-marker",
    version="0.1.0",
    author="Radu Ciorba",
    author_email="radu@devrandom.ro",
    maintainer="Radu Ciorba",
    maintainer_email="radu@devrandom.ro",
    license="MIT",
    url="https://github.com/rciorba/pytest-fixture-marker",
    description="A pytest plugin to add markers based on fixtures used.",
    long_description=read("README.rst"),
    py_modules=["pytest_fixture_marker"],
    python_requires=">=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*",
    install_requires=["pytest>=3.5.0"],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Framework :: Pytest",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Testing",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Operating System :: OS Independent",
        "License :: OSI Approved :: MIT License",
    ],
    entry_points={"pytest11": ["fixture-marker = pytest_fixture_marker"]},
)

==> pytest-fixture-marker-1.0.0.tar.gz: pytest-fixture-marker-1.0.0/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import codecs
from setuptools import setup


def read(fname):
    file_path = os.path.join(os.path.dirname(__file__), fname)
    return codecs.open(file_path, encoding="utf-8").read()


setup(
    name="pytest-fixture-marker",
    version="1.0.0",
    author="Radu Ciorba",
    author_email="radu@devrandom.ro",
    maintainer="Radu Ciorba",
    maintainer_email="radu@devrandom.ro",
    license="MIT",
    url="https://github.com/rciorba/pytest-fixture-marker",
    description="A pytest plugin to add markers based on fixtures used.",
    long_description=read("README.rst"),
    py_modules=["pytest_fixture_marker"],
    python_requires=">=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*",
    install_requires=["pytest>=3.5.0"],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Framework :: Pytest",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Testing",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Operating System :: OS Independent",
        "License :: OSI Approved :: MIT License",
    ],
    entry_points={"pytest11": ["fixture-marker = pytest_fixture_marker"]},
)
